@@ -1,5 +1,5 @@
 # commands/rinfo.py
-# Copyright (C) 2011-2012 Andrew Svetlov
+# Copyright (C) 2011-2014 Andrew Svetlov
 # andrew.svetlov@gmail.com
 #
 # This module is part of BloggerTool and is released under
@@ -20,25 +20,23 @@ class RInfoCommand(BaseCommand):
 
     @classmethod
     def fill_parser(cls, parser):
-        pass
+        parser.add_argument('--reset_credentials', default=False,
+                            action='store_true',
+                            help="reset stored credentials")
 
     def __init__(self, args):
-        #self.email = args.email
-        pass
+        self.reset_credentials = args.reset_credentials
 
     def run(self):
         config = self.config
 
         info = config.info
 
-        if not info.email:
-            raise ConfigError("Set user email first")
-
-        srv = info.remote()
+        srv = info.remote(self.reset_credentials)
 
         blogs = srv.get_blogs()
         out = []
         for blog in blogs:
-            out.append("    [%s] %s" % (blog.blogid, blog.title))
+            out.append("    [%s->%s] %s" % (blog.blogid, blog.url, blog.title))
         self.log.info("Blogs of user '%s'\n%s", blogs.title,
                       '\n'.join(out))
